@@ -142,7 +142,7 @@ class OptionAlwaysShown(OptionInterface):
                 self.widget.clear()
                 if type(supported) == list:
                     for each in supported:
-                        self.widget.addItem(each)
+                        self.widget.addItem(unicode(each))
                 else:
                     self.widget.addItem(supported)
         if original_value != None:
@@ -318,7 +318,7 @@ class OptionSelectOne(Option):
     def __init__(self, name, value, supported, on_change):
         Option.__init__(self, name, value, supported, on_change)
 
-        self.selector = QComboBox(self)
+        self.selector = QComboBox()
 
         selected = None
         for nr, choice in enumerate(supported):
